From 5c7008dbe538c36d5f41b844b3ac9bb5cdcc8f73 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Andreas=20=C3=85kre=20Solberg?= <andreas.solberg@uninett.no>
Date: Wed, 14 Jan 2009 22:41:44 +0000
Subject: [PATCH] Fix spelling mistake on incomming versus incoming. Thanks
 Simon.

git-svn-id: https://simplesamlphp.googlecode.com/svn/trunk@1150 44740490-163a-0410-bde0-09ae8108e29a
---
 docs/source/simplesamlphp-idp.xml                      |  4 ++--
 www/errorreport.php                                    |  2 +-
 www/saml2/idp/SSOService.php                           |  8 ++++----
 www/saml2/idp/SingleLogoutService.php                  |  4 ++--
 .../idp/SingleLogoutServiceiFrameNoJavascript.php      |  2 +-
 www/saml2/idp/SingleLogoutServiceiFrameResponse.php    |  2 +-
 www/shib13/idp/SSOService.php                          | 10 +++++-----
 7 files changed, 16 insertions(+), 16 deletions(-)

diff --git a/docs/source/simplesamlphp-idp.xml b/docs/source/simplesamlphp-idp.xml
index cc8908dba..909de27b3 100644
--- a/docs/source/simplesamlphp-idp.xml
+++ b/docs/source/simplesamlphp-idp.xml
@@ -1220,7 +1220,7 @@ openssl x509 -req -days 60 -in server2.csr -signkey server2.key -out server2.crt
       <para>The authentication plugin should be placed in the
       <filename>auth</filename> directory.</para>
 
-      <para>The following parameters must be accepted in the incomming
+      <para>The following parameters must be accepted in the incoming
       URL:</para>
 
       <itemizedlist>
@@ -1230,7 +1230,7 @@ openssl x509 -req -days 60 -in server2.csr -signkey server2.key -out server2.crt
         </listitem>
 
         <listitem>
-          <para><literal>RequestID</literal>: ID of an incomming
+          <para><literal>RequestID</literal>: ID of an incoming
           request.</para>
         </listitem>
       </itemizedlist>
diff --git a/www/errorreport.php b/www/errorreport.php
index eb3a1b472..28ab5d168 100644
--- a/www/errorreport.php
+++ b/www/errorreport.php
@@ -18,7 +18,7 @@ if($_SERVER['REQUEST_METHOD'] !== 'POST') {
  * POST fields will be added to the email in the order they appear here, and with the description
  * from the value in the array.
  *
- * DEPRECATED. Included as reference of incomming parameters.
+ * DEPRECATED. Included as reference of incoming parameters.
  */
 $mailFormat = array(
 	'email' => 'Email address of submitter',
diff --git a/www/saml2/idp/SingleLogoutService.php b/www/saml2/idp/SingleLogoutService.php
index f38e74e70..22e2caa9f 100644
--- a/www/saml2/idp/SingleLogoutService.php
+++ b/www/saml2/idp/SingleLogoutService.php
@@ -1,7 +1,7 @@
 <?php
 
 /**
- * This SAML 2.0 endpoint can receive incomming LogoutRequests. It will also send LogoutResponses, 
+ * This SAML 2.0 endpoint can receive incoming LogoutRequests. It will also send LogoutResponses, 
  * and LogoutRequests and also receive LogoutResponses. It is implemeting SLO at the SAML 2.0 IdP.
  *
  * @author Andreas Ă…kre Solberg, UNINETT AS. <andreas.solberg@uninett.no>
@@ -82,7 +82,7 @@ function saveLogoutInfo($id) {
 
 
 /**
- * If we get an incomming LogoutRequest then we initiate the logout process.
+ * If we get an incoming LogoutRequest then we initiate the logout process.
  * in this case an SAML 2.0 SP is sending an request, which also is referred to as
  * SP initiated Single Logout.
  *
diff --git a/www/saml2/idp/SingleLogoutServiceiFrameNoJavascript.php b/www/saml2/idp/SingleLogoutServiceiFrameNoJavascript.php
index 8fa0eb9c4..73a7b0147 100644
--- a/www/saml2/idp/SingleLogoutServiceiFrameNoJavascript.php
+++ b/www/saml2/idp/SingleLogoutServiceiFrameNoJavascript.php
@@ -1,7 +1,7 @@
 <?php
 
 /**
- * This SAML 2.0 endpoint can receive incomming LogoutRequests. It will also send LogoutResponses, 
+ * This SAML 2.0 endpoint can receive incoming LogoutRequests. It will also send LogoutResponses, 
  * and LogoutRequests and also receive LogoutResponses. It is implemeting SLO at the SAML 2.0 IdP.
  *
  * @author Andreas Ă…kre Solberg, UNINETT AS. <andreas.solberg@uninett.no>
diff --git a/www/saml2/idp/SingleLogoutServiceiFrameResponse.php b/www/saml2/idp/SingleLogoutServiceiFrameResponse.php
index 90161d4f4..545039d93 100644
--- a/www/saml2/idp/SingleLogoutServiceiFrameResponse.php
+++ b/www/saml2/idp/SingleLogoutServiceiFrameResponse.php
@@ -2,7 +2,7 @@
 
 
 /**
- * This SAML 2.0 endpoint can receive incomming LogoutResponses. 
+ * This SAML 2.0 endpoint can receive incoming LogoutResponses. 
  *
  * @author Andreas Ă…kre Solberg, UNINETT AS. <andreas.solberg@uninett.no>
  * @package simpleSAMLphp
diff --git a/www/saml2/idp/SSOService.php b/www/saml2/idp/SSOService.php
index 101088226..b1fe63cfc 100644
--- a/www/saml2/idp/SSOService.php
+++ b/www/saml2/idp/SSOService.php
@@ -1,6 +1,6 @@
 <?php
 /**
  * The SSOService is part of the SAML 2.0 IdP code, and it receives incomming Authentication Requests
  * from a SAML 2.0 SP, parses, and process it, and then authenticates the user and sends the user back
  * to the SP with an Authentication Response.
  *
@@ -35,7 +35,7 @@ if (!$config->getValue('enable.saml20-idp', false))
 
 
 /*
  * If the SAMLRequest query parameter is set, we got an incomming Authentication Request 
  * at this interface.
  *
  * In this case, what we should do is to process the request and set the neccessary information
@@ -114,7 +114,7 @@ if (isset($_GET['SAMLRequest'])) {
 	}
 
 /*
  * If we did not get an incomming Authenticaiton Request, we need a RequestID parameter.
  *
  * The RequestID parameter is used to retrieve the information stored in the session object
  * related to the request that was received earlier. Usually the request is processed with 
@@ -126,7 +126,7 @@ if (isset($_GET['SAMLRequest'])) {
 
 	try {
 	
-		SimpleSAML_Logger::info('SAML2.0 - IdP.SSOService: Got incomming authentication ID');
+		SimpleSAML_Logger::info('SAML2.0 - IdP.SSOService: Got incoming authentication ID');
 		
 		$authId = $_GET['RequestID'];
 		$requestcache = $session->getAuthnRequest('saml2', $authId);
@@ -1,6 +1,6 @@
 <?php
 /**
- * The SSOService is part of the SAML 2.0 IdP code, and it receives incomming Authentication Requests
+ * The SSOService is part of the SAML 2.0 IdP code, and it receives incoming Authentication Requests
  * from a SAML 2.0 SP, parses, and process it, and then authenticates the user and sends the user back
  * to the SP with an Authentication Response.
@@ -35,7 +35,7 @@ if (!$config->getValue('enable.saml20-idp', false))
 
 /*
- * If the SAMLRequest query parameter is set, we got an incomming Authentication Request 
+ * If the SAMLRequest query parameter is set, we got an incoming Authentication Request 
  * at this interface.
  *
@@ -114,7 +114,7 @@ if (isset($_GET['SAMLRequest'])) {
 
 /*
- * If we did not get an incomming Authenticaiton Request, we need a RequestID parameter.
+ * If we did not get an incoming Authenticaiton Request, we need a RequestID parameter.
  *
  * The RequestID parameter is used to retrieve the information stored in the session object
diff --git a/www/shib13/idp/SSOService.php b/www/shib13/idp/SSOService.php
index 8068af3a3..638c43d7d 100644
--- a/www/shib13/idp/SSOService.php
+++ b/www/shib13/idp/SSOService.php
@@ -1,6 +1,6 @@
 <?php
 /**
  * The SSOService is part of the Shibboleth 1.3 IdP code, and it receives incomming Authentication Requests
  * from a Shibboleth 1.3 SP, parses, and process it, and then authenticates the user and sends the user back
  * to the SP with an Authentication Response.
  *
@@ -30,7 +30,7 @@ try {
 }
 
 /*
  * If the shire query parameter is set, we got an incomming Authentication Request 
  * at this interface.
  *
  * In this case, what we should do is to process the request and set the neccessary information
@@ -56,7 +56,7 @@ if (isset($_GET['shire'])) {
 			'RelayState' => $authnrequest->getRelayState(),
 		);
 			
-		SimpleSAML_Logger::info('Shib1.3 - IdP.SSOService: Got incomming Shib authnRequest requestid: '.$requestid);
+		SimpleSAML_Logger::info('Shib1.3 - IdP.SSOService: Got incoming Shib authnRequest requestid: '.$requestid);
 	
 	} catch(Exception $exception) {
 		SimpleSAML_Utilities::fatalError($session->getTrackID(), 'PROCESSAUTHNREQUEST', $exception);
@@ -64,7 +64,7 @@ if (isset($_GET['shire'])) {
 
 
 /*
  * If we did not get an incomming Authenticaiton Request, we need a RequestID parameter.
  *
  * The RequestID parameter is used to retrieve the information stored in the session object
  * related to the request that was received earlier. Usually the request is processed with 
@@ -80,7 +80,7 @@ if (isset($_GET['shire'])) {
 
 		$requestcache = $session->getAuthnRequest('shib13', $authId);
 		
-		SimpleSAML_Logger::info('Shib1.3 - IdP.SSOService: Got incomming RequestID: '. $authId);
+		SimpleSAML_Logger::info('Shib1.3 - IdP.SSOService: Got incoming RequestID: '. $authId);
 		
 		if (!$requestcache) {
 			throw new Exception('Could not retrieve cached RequestID = ' . $authId);
@@ -1,6 +1,6 @@
 <?php
 /**
- * The SSOService is part of the Shibboleth 1.3 IdP code, and it receives incomming Authentication Requests
+ * The SSOService is part of the Shibboleth 1.3 IdP code, and it receives incoming Authentication Requests
  * from a Shibboleth 1.3 SP, parses, and process it, and then authenticates the user and sends the user back
  * to the SP with an Authentication Response.
@@ -30,7 +30,7 @@ try {
 
 /*
- * If the shire query parameter is set, we got an incomming Authentication Request 
+ * If the shire query parameter is set, we got an incoming Authentication Request 
  * at this interface.
  *
@@ -64,7 +64,7 @@ if (isset($_GET['shire'])) {
 
 /*
- * If we did not get an incomming Authenticaiton Request, we need a RequestID parameter.
+ * If we did not get an incoming Authenticaiton Request, we need a RequestID parameter.
  *
  * The RequestID parameter is used to retrieve the information stored in the session object
-- 
GitLab